==================================================
pytag -- Yet another tool to handle audio metadata
==================================================


pytag is a Python 3 library to handle audio metadata.


Documentation
-------------

Documentation for pytag is hosted at http://readthedocs.org/docs/cliff/en/latest/


Status
------

.. image:: https://secure.travis-ci.org/dhellmann/cliff.png?branch=master

